==> yybbs-0.57.zip: yybbs/sql/mysql.sql <==
CREATE TABLE yybbs (
  id int(10) NOT NULL auto_increment,
  serial int(10) NOT NULL,
  bbs_id tinyint(3) NOT NULL default '1',
  uid mediumint(5) NOT NULL default '0',
  name varchar(64) default NULL,
  email varchar(64) default NULL,
  url varchar(64) default NULL,
  title varchar(64) default NULL,
  message text,
  icon varchar(24) NOT NULL default '',
  col char(8) NOT NULL default '0',
  passwd varchar(34) NOT NULL default '',
  parent int(10) NOT NULL default '0',
  inputdate int(10) NOT NULL default '0',
  update_date int(10) NOT NULL default '0',
  ip varchar(22) NOT NULL default '',
  PRIMARY KEY  (id)
) TYPE=MyISAM;

CREATE TABLE yybbs_faceicon (
   id mediumint(5) DEFAULT '1' NOT NULL auto_increment,
   name varchar(32) NOT NULL,
   icon varchar(30) DEFAULT 0 NOT NULL,
   priority tinyint(3) DEFAULT '0' NOT NULL,
   bbs_id tinyint(3) DEFAULT '1' NOT NULL,
   type tinyint(1) DEFAULT 0 NOT NULL,
   PRIMARY KEY (id)
) TYPE=MyISAM;

CREATE TABLE yybbs_bbs (
   bbs_id tinyint(3) DEFAULT '1' NOT NULL auto_increment,
   title varchar(64) DEFAULT '' NOT NULL,
   page_limit tinyint (2) DEFAULT '5' NOT NULL,
   ex text DEFAULT '' NOT NULL,
   howto text DEFAULT '' NOT NULL,
   color varchar(128) DEFAULT '#800000 #DF0000 #008040 #0000FF #C100C1 #FF80C0 #FF8040 #000080' NOT NULL,
   template_dir varchar(64) NOT NULL,
   windows_opt varchar(16) NOT NULL,
   serial int(10) DEFAULT 1 NOT NULL,
   xooops_use tinyint(1) DEFAULT 1 NOT NULL,
   priority tinyint(2) DEFAULT 0 NOT NULL,
   status tinyint(1) DEFAULT 0 NOT NULL,
   PRIMARY KEY (bbs_id)
) TYPE=MyISAM;

==> yybbs-0.58.zip: yybbs/sql/mysql.sql <==
CREATE TABLE yybbs (
  id int(10) NOT NULL auto_increment,
  serial int(10) NOT NULL,
  bbs_id tinyint(3) NOT NULL default '1',
  uid mediumint(5) NOT NULL default '0',
  name varchar(64) default NULL,
  email varchar(64) default NULL,
  url varchar(64) default NULL,
  title varchar(64) default NULL,
  message text,
  icon varchar(24) NOT NULL default '',
  col char(8) NOT NULL default '0',
  passwd varchar(34) NOT NULL default '',
  parent int(10) NOT NULL default '0',
  inputdate int(10) NOT NULL default '0',
  update_date int(10) NOT NULL default '0',
  ip varchar(22) NOT NULL default '',
  PRIMARY KEY  (id)
) TYPE=MyISAM;

CREATE TABLE yybbs_faceicon (
   id mediumint(5) NOT NULL auto_increment,
   name varchar(32) NOT NULL,
   icon varchar(30) DEFAULT 0 NOT NULL,
   priority tinyint(3) DEFAULT '0' NOT NULL,
   bbs_id tinyint(3) DEFAULT '1' NOT NULL,
   type tinyint(1) DEFAULT 0 NOT NULL,
   PRIMARY KEY (id)
) TYPE=MyISAM;

CREATE TABLE yybbs_bbs (
   bbs_id tinyint(3) NOT NULL auto_increment,
   title varchar(64) DEFAULT '' NOT NULL,
   page_limit tinyint (2) DEFAULT '5' NOT NULL,
   ex text DEFAULT '' NOT NULL,
   howto text DEFAULT '' NOT NULL,
   color varchar(128) DEFAULT '#800000 #DF0000 #008040 #0000FF #C100C1 #FF80C0 #FF8040 #000080' NOT NULL,
   template_dir varchar(64) NOT NULL,
   windows_opt varchar(16) NOT NULL,
   serial int(10) DEFAULT 1 NOT NULL,
   xooops_use tinyint(1) DEFAULT 1 NOT NULL,
   priority tinyint(2) DEFAULT 0 NOT NULL,
   status tinyint(1) DEFAULT 0 NOT NULL,
   PRIMARY KEY (bbs_id)
) TYPE=MyISAM;
